@@ -4,7 +4,7 @@ describe 'swift::storage::node' do
     OSDefaults.get_facts({
       :operatingsystem => 'Ubuntu',
       :osfamily        => 'Debian',
-      :processorcount  => 1,
+      :os_workers      => 1,
     })
   end
 
